===============
Getting Started
===============

To use swolfpy, do the following steps:

1- Activate the environment::

        conda activate swolfpy

2- Open python to run swolfpy::

        ipython

3- Run swolfpy in python::

        from swolfpy import *
        swolfpy()

.. image:: /Images/Tab_Start.png
   :scale: 60 %
   :alt: alternate text
   :align: left
